==> ovito_3.10.5~ds.orig.tar.xz: ovito-v3.10.5/src/ovito/core/dataset/animation/controller/LinearInterpolationControllers.cpp <==
////////////////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2023 OVITO GmbH, Germany
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify it either under the
//  terms of the GNU General Public License version 3 as published by the Free Software
//  Foundation (the "GPL") or, at your option, under the terms of the MIT License.
//  If you do not alter this notice, a recipient may use your version of this
//  file under either the GPL or the MIT License.
//
//  You should have received a copy of the GPL along with this program in a
//  file LICENSE.GPL.txt.  You should have received a copy of the MIT License along
//  with this program in a file LICENSE.MIT.txt
//
//  This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
//  either express or implied. See the GPL or the MIT License for the specific language
//  governing rights and limitations.
//
////////////////////////////////////////////////////////////////////////////////////////

#include <ovito/core/Core.h>
#include "LinearInterpolationControllers.h"

namespace Ovito {

IMPLEMENT_OVITO_CLASS(LinearFloatController);
IMPLEMENT_OVITO_CLASS(LinearIntegerController);
IMPLEMENT_OVITO_CLASS(LinearVectorController);
IMPLEMENT_OVITO_CLASS(LinearPositionController);
IMPLEMENT_OVITO_CLASS(LinearRotationController);
IMPLEMENT_OVITO_CLASS(LinearScalingController);

}   // End of namespace

==> ovito_3.13.1~ds.orig.tar.xz: ovito-v3.13.1/src/ovito/core/dataset/animation/controller/LinearInterpolationControllers.cpp <==
////////////////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2025 OVITO GmbH, Germany
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify it either under the
//  terms of the GNU General Public License version 3 as published by the Free Software
//  Foundation (the "GPL") or, at your option, under the terms of the MIT License.
//  If you do not alter this notice, a recipient may use your version of this
//  file under either the GPL or the MIT License.
//
//  You should have received a copy of the GPL along with this program in a
//  file LICENSE.GPL.txt.  You should have received a copy of the MIT License along
//  with this program in a file LICENSE.MIT.txt
//
//  This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
//  either express or implied. See the GPL or the MIT License for the specific language
//  governing rights and limitations.
//
////////////////////////////////////////////////////////////////////////////////////////

#include <ovito/core/Core.h>
#include "LinearInterpolationControllers.h"

namespace Ovito {

IMPLEMENT_CREATABLE_OVITO_CLASS(LinearFloatController);
IMPLEMENT_CREATABLE_OVITO_CLASS(LinearIntegerController);
IMPLEMENT_CREATABLE_OVITO_CLASS(LinearVectorController);
IMPLEMENT_CREATABLE_OVITO_CLASS(LinearPositionController);
IMPLEMENT_CREATABLE_OVITO_CLASS(LinearRotationController);
IMPLEMENT_CREATABLE_OVITO_CLASS(LinearScalingController);

}   // End of namespace
